Package: eiPack
Type: Package
Version: 0.2-2
Date: 2023-02-18
Title: Ecological Inference and Higher-Dimension Data Management
Author: Olivia Lau <olivia.lau@post.harvard.edu>, Ryan T. Moore
        <rtm@american.edu>, Michael Kellermann <mrkellermann@gmail.com>
Maintainer: Michael Kellermann <mrkellermann@gmail.com>
Depends: R (>= 2.0.0)
Imports: MASS, coda, msm
Suggests: lattice
Description: Provides methods for analyzing R by C ecological contingency
        tables using the extreme case analysis, ecological regression,
        and Multinomial-Dirichlet ecological inference models.  Also
        provides tools for manipulating higher-dimension data objects.
License: GPL (>= 2) | file LICENSE
URL: http://www.olivialau.org/software/
NeedsCompilation: yes
Packaged: 2023-02-18 22:43:58 UTC; Mike Kellermann
Repository: CRAN
Date/Publication: 2023-02-18 23:40:02 UTC
