\name{tuneA}
\alias{tuneA}

\title{Tuning parameters for alpha hyperpriors in RxC EI model}

\description{ Tuning parameters for hyperpriors in RxC EI model
}

\usage{data(tuneA)}

\format{A table containing 3 rows and 3 columns.}

\keyword{datasets}
